@@ -1,5 +1,6 @@
 package Perl::Critic::Policy::Documentation::RequirePod;
-$Perl::Critic::Policy::Documentation::RequirePod::VERSION = '0.002';
+# ABSTRACT: file requires POD
+$Perl::Critic::Policy::Documentation::RequirePod::VERSION = '0.003';
 use utf8;
 use strict;
 use warnings;
@@ -43,8 +44,6 @@ sub violates {
 
 __END__
 
-# ABSTRACT: file requires POD
-
 =pod
 
 =encoding UTF-8
@@ -53,8 +52,27 @@ __END__
 
 Perl::Critic::Policy::Documentation::RequirePod - file requires POD
 
+=head1 VERSION
+
+version 0.003
+
 =head1 DESCRIPTION
 
 This policy requires your code to contain POD.
 
+=head1 NAME
+
+Perl::Critic::Policy::Documentation::RequirePod - file requires POD
+
+=head1 AUTHOR
+
+Andreas Schröter <andreas.schroeter@autinity.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by afr-consulting GmbH.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
